import requests
import json

class Userget:
    def __init__(self,uid):
        self.uid = str(uid)
        self.headers = {
        "User-Agent":"Bili fans/1.0.0 (18108274905@163.com)",
        "Host":"api.bilibili.com",
        "Connection":"keep-alive"
        }
        #获取账户信息
        self.info_url = 'https://api.bilibili.com/x/relation/stat?jsonp=jsonp&vmid=' + self.uid
        self.user_info_j = json.loads(requests.get(self.info_url,headers=self.headers).text)
        
        #up信息
        self.upinfo_url = "https://api.bilibili.com/x/space/acc/info?mid="+ self.uid +"&jsonp=jsonp"
        self.up_info_j = json.loads(requests.get(self.upinfo_url,headers=self.headers).text)

        #获取直播信息
        self.live_url = "https://api.live.bilibili.com/room/v1/Room/getRoomInfoOld?mid=" + self.uid
        self.user_live_j = json.loads(requests.get(self.live_url).text)

        #大体视频信息
        self.video_list_url = "https://space.bilibili.com/ajax/member/getSubmitVideos?mid=" + self.uid
        self.big_video_j = json.loads(requests.get(self.video_list_url).text)




    #账户信息回调
    def userinfo(self):
        '''
        用户一般信息json
        '''
        return self.user_info_j

    def id(self):
        '''
        用户uid int
        '''
        return self.user_info_j['data']['mid']

    def following(self):
        '''
        用户关注数 int 
        '''
        return self.user_info_j['data']['following']

    def whisper(self):
        '''
        用户私信数 int 一般无法获取
        '''
        return self.user_info_j['data']['whisper']

    def black(self):
        '''
        用户黑名单数 int
        '''
        return self.user_info_j['data']['black']

    def follower(self):
        '''
        用户粉丝数 int
        '''
        return self.user_info_j['data']['follower']

    #up信息回调
    def upinfo(self):
        '''
        用户具体信息json
        '''
        return self.up_info_j
    
    def username(self):
        '''
        用户名 str
        '''
        return self.up_info_j['data']['name']

    def sex(self):
        '''
        用户性别 str 
        '''
        return self.up_info_j['data']['sex']

    def face(self):
        '''
        用户头像链接 str
        '''
        return self.up_info_j['data']['face']
    
    def sign(self):
        '''
        用户个性签名 str
        '''
        return self.up_info_j['data']['sign']
    
    def level(self):
        '''
        用户等级 int
        '''
        return self.up_info_j['data']['level']
    
    def birthday(self):
        '''
        用户生日 mm-dd   str
        '''
        return self.up_info_j['data']['birthday']
    
    def badge(self):
        '''
        用户是否自己的粉丝勋章  Boolean
        '''
        return self.up_info_j['data']['fans_badge']
    
    def intr(self):
        '''
        用户的认证信息 str
        '''
        return self.up_info_j['data']['official']['title']

    def viptype(self):
        '''
        用户vip类别 int
        0:无  1:普通VIP 2:年费VIP
        '''
        return self.up_info_j['data']['vip']['type']

    def vipthemetype(self):
        '''
        vip主题状态 Boolean
        '''
        return self.up_info_j['data']['vip']['theme_type']

    def isfollowed(self):
        '''
        是否可以被直接关注 Boolean
        '''
        return self.up_info_j['data']['is_followed']

    def toppic(self):
        '''
        主页顶部图片url str
        '''
        return self.up_info_j['data']['top_photo']


    #直播信息回调
    def liveinfo(self):
        return self.user_live_j

    def liveurl(self):
        '''
        直播间链接 str
        '''
        return self.user_live_j['data']['url']

    def liveroomid(self):
        '''
        直播间号 int
        '''
        return self.user_live_j['data']['roomid']

    def liveroomcover(self):
        '''
        直播间封面链接 str
        '''
        return self.user_live_j['data']['cover']

    
    #大体视频信息回调
    def uservideoinfo(self):
        return self.big_video_j
    
    def usertags(self):
        '''
        用户视频标签list [str,...]
        '''
        tlist = [tag for tag in self.big_video_j['data']['tlist']]
        tags = [tag for tag in tlist['name']]
        return tags
    
    def newv(self):
        '''
        用户最新视频id int
        '''
        return self.big_video_j['data']['vlist'][0]['aid']


class Videoget:
    def __init__(self,aid):
        self.aid = str(aid)
        self.headers = {
        "User-Agent":"Bili fans/1.0.0 (18108274905@163.com)",
        "Host":"api.bilibili.com",
        "Connection":"keep-alive"
        }
        
        #获取视频基本信息
        self.vnum_url = 'https://api.bilibili.com/x/web-interface/archive/stat?aid=' + self.aid
        self.vnum_j = json.loads(requests.get(self.vnum_url,headers=self.headers).text)

        #获取视频详细信息
        self.vinfo_url = 'https://api.bilibili.com/x/web-interface/view?aid=' + self.aid
        self.vinfo_j = json.loads(requests.get(self.vinfo_url,headers=self.headers).text)

        #获取视频下载信息 kanbilibili.com
        self.vd_url = 'https://www.kanbilibili.com/api/video/'+ self.aid +'/download?cid=101560001&quality=64&page=1'
        self.vd_j = json.loads(requests.get(self.vd_url,headers=self.headers).text)


    #基本信息回调
    def id(self):
        return int(self.vnum_j['data']['aid'])

    def view(self):
        '''
        观看数 int
        '''
        return self.vnum_j['data']['view']

    def dan(self):
        '''
        弹幕数 int 
        '''
        return self.vnum_j['data']['danmaku']
    
    def reply(self):
        '''
        评论数
        '''
        return self.vnum_j['data']['reply']

    def favorite(self):
        '''
        收藏数 int
        '''
        return self.vnum_j['data']['favorite']

    def coin(self):
        '''
        硬币数 int
        '''
        return self.vnum_j['data']['coin']

    def share(self):
        '''
        分享数 int
        '''
        return self.vnum_j['data']['share']
    
    def like(self):
        '''
        点赞数 int
        '''
        return self.vnum_j['data']['like']
    
    def copyright(self):
        '''
        版权状态 int
        '''
        return self.vnum_j['data']['copyright']

    #杂项信息回调
    def detail(self):
        return self.vinfo_j

    def ownerid(self):
        '''
        视频主人id int
        '''
        return self.vinfo_j['data']['owner']['mid']

    def title(self):
        '''
        视频标题 str
        '''
        return self.vinfo_j['data']['title']
    
    def cover(self):
        '''
        视频封面url str
        '''
        return self.vinfo_j['data']['pic']

    def desc(self):
        '''
        视频简介 str
        '''
        return self.vinfo_j['data']['desc']


# class Downv:
    # def __init__(self,aid):
        # self.aid = str(aid)
        # self.headers = {
        # "User-Agent":"Bili fans/1.0.0 (18108274905@163.com)",
        # "Host":"api.bilibili.com",
        # "Connection":"keep-alive"
        # }

        # #获取视频下载信息 kanbilibili.com
        # self.vd_url = 'https://www.kanbilibili.com/api/video/'+ self.aid +'/download?cid=101560001&quality=64&page=1'
        # self.vd_j = json.loads(requests.Session().get(self.vd_url).text)
        # self.dj = self.vd_j['data']['durl'][0] 

    # def url(self):
        # dlist = [self.vd_j['data']['durl'][0]['url'],self.vd_j['data']['durl'][0]['backup_url']]
        # return dlist
    
    # def formats(self):
        # return self.vd_j['data']['format']
    
    # def size(self):
        # return self.dj['size']
    
    # def time(self):
        # return self.dj['length']



import  requests
import json

class Ds:
    def __init__(self):
        self.__doc__ = '返回搜索框默认内容'
        self.burl = 'https://api.bilibili.com/x/web-interface/search/default'
        self.ds_json = json.loads(requests.get(self.burl).text)
        self.dstypenum = self.ds_json['data']['goto_type']

    def showname(self):
        '''
        返回搜索框内容 str
        '''
        return self.ds_json['data']['show_name']
    
    def dstype(self):
        '''
        返回指向页面类型 1为视频 int
        '''
        return self.dstypenum

    def value(self):
        '''
        判断类型并给出值
        如果为视频： ['video',aid] || aid->int
        如果为其他： ['other',...]
        '''
        if self.dstypenum == 1:
            return ['video',int(self.ds_json['data']['goto_value'])]
        else:
            return ['other',self.ds_json['data']['goto_value']]

    def url(self):
        '''
        返回指向url
        '''
        return self.ds_json['data']['url']

    def all(self):
        return self.ds_json



import requests
import json
# import matplotlib.pyplot as plt
# import numpy as np

class Fanslook:
    def __init__(self,page=5):
        self.__doc__ = '数据来源：biliob.com \n 网站作者：Jannchie见齐'

        self.headers = {
        "User-Agent":"Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3282.204 Safari/537.36",
        }
        self.burl = 'https://www.biliob.com/api/event/fans-variation?pagesize=' + str(page)

        self.fjson = json.loads(requests.get(self.burl,headers=self.headers).text)
        self.case = self.fjson['content']
        self.fans_list = [[p["author"],p["mid"],p["variation"]] for p in self.case ]
    
    def fans(self):
        return self.fans_list

    def copyright(self):
        print('''
        数据来源：biliob.com \n 
        网站作者：Jannchie见齐 \n
        模块作者:Lixiaobai
        ''')

class Bilitime:
    def __init__(self):
        self.headers = {
        "User-Agent":"Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3282.204 Safari/537.36",
        }
        self.turl = 'https://www.biliob.com/api/site'
        self.tjson = json.loads(requests.get(self.turl,headers=self.headers).text)

        self.playlist = [playitem['playOnline'] for playitem in self.tjson]
        self.weblist = [playitem['webOnline'] for playitem in self.tjson]
        self.datelist = [playitem['datetime'] for playitem in self.tjson]

    # def draw(self):
        # plt.rcParams['font.sans-serif'] = ['KaiTi'] # 指定默认字体
        # plt.rcParams['axes.unicode_minus'] = False # 解决保存图像是负号'-'显示为方块的问题

        # plt.title("在线人数，观看数曲线") 
        
        # x1 = np.array([i+1 for i in range(len(self.playlist))][::-1])
        # y1 = np.array(self.playlist)
        # plt.plot(x1,y1,color = 'dodgerblue',label = "播放人数")# 折线 1 x 2 y 3 color

        # x2 = np.array([i+1 for i in range(len(self.weblist))][::-1])
        # y2 = np.array(self.weblist)
        # plt.plot(x2,y2,color = 'yellow',label = "在线人数")# 折线 1 x 2 y 3 color

        # plt.show()
    
    def zipped(self):
        self.zipper =[]
        for i in range(len(self.playlist)):
            self.zipper.append([self.playlist[i],self.weblist[i],self.datelist[i]])
        return self.zipper
